@@ -4,14 +4,13 @@ context("tree construction")
 data(acme)
 
 test_that("isRoot", {
+  data(acme)
   
   expect_equal(acme$isRoot, TRUE)
   
-  it <- acme$Find("IT")
-  expect_equal(it$isRoot, FALSE)
+  expect_equal(acme$IT$isRoot, FALSE)
   
-  agile <- it$Find("Go agile")
-  expect_equal(agile$isRoot, FALSE)
+  expect_equal(acme$IT$`Go agile`$isRoot, FALSE)
 })
 
 
@@ -24,20 +23,20 @@ test_that("totalCount", {
   expect_equal(acme$totalCount, 11)
 })
 
-test_that("Find", {
+test_that("Climb", {
   
   
-  node <- acme$Find("Accounting", "New Accounting Standards")
+  node <- acme$Climb("Accounting", "New Accounting Standards")
   expect_equal(node$name, "New Accounting Standards")
   
-  node <- acme$Find("Not existing node")
+  node <- acme$Climb("Not existing node")
   expect_equal(node, NULL)
   
 })
 
 test_that("isLeaf", {
   
-  node <- acme$Find("Accounting", "New Accounting Standards")
+  node <- acme$Climb("Accounting", "New Accounting Standards")
   expect_equal(node$isLeaf, TRUE)
   
 })
@@ -47,10 +46,10 @@ test_that("level", {
   
   expect_equal(acme$isLeaf, FALSE)
   
-  accounting <- acme$Find("Accounting")
+  accounting <- acme$Climb("Accounting")
   expect_equal(accounting$isLeaf, FALSE)
   
-  node <- accounting$Find("New Accounting Standards")
+  node <- accounting$Climb("New Accounting Standards")
   expect_equal(node$isLeaf, TRUE)
   
 })
